'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_float_buffer'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_float_buffer',error_checker=_errors._error_checker)
GL_FLOAT_CLEAR_COLOR_VALUE_NV=_C('GL_FLOAT_CLEAR_COLOR_VALUE_NV',0x888D)
GL_FLOAT_R16_NV=_C('GL_FLOAT_R16_NV',0x8884)
GL_FLOAT_R32_NV=_C('GL_FLOAT_R32_NV',0x8885)
GL_FLOAT_RG16_NV=_C('GL_FLOAT_RG16_NV',0x8886)
GL_FLOAT_RG32_NV=_C('GL_FLOAT_RG32_NV',0x8887)
GL_FLOAT_RGB16_NV=_C('GL_FLOAT_RGB16_NV',0x8888)
GL_FLOAT_RGB32_NV=_C('GL_FLOAT_RGB32_NV',0x8889)
GL_FLOAT_RGBA16_NV=_C('GL_FLOAT_RGBA16_NV',0x888A)
GL_FLOAT_RGBA32_NV=_C('GL_FLOAT_RGBA32_NV',0x888B)
GL_FLOAT_RGBA_MODE_NV=_C('GL_FLOAT_RGBA_MODE_NV',0x888E)
GL_FLOAT_RGBA_NV=_C('GL_FLOAT_RGBA_NV',0x8883)
GL_FLOAT_RGB_NV=_C('GL_FLOAT_RGB_NV',0x8882)
GL_FLOAT_RG_NV=_C('GL_FLOAT_RG_NV',0x8881)
GL_FLOAT_R_NV=_C('GL_FLOAT_R_NV',0x8880)
GL_TEXTURE_FLOAT_COMPONENTS_NV=_C('GL_TEXTURE_FLOAT_COMPONENTS_NV',0x888C)

