'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_sync'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_sync',error_checker=_errors._error_checker)
GL_ALREADY_SIGNALED=_C('GL_ALREADY_SIGNALED',0x911A)
GL_CONDITION_SATISFIED=_C('GL_CONDITION_SATISFIED',0x911C)
GL_MAX_SERVER_WAIT_TIMEOUT=_C('GL_MAX_SERVER_WAIT_TIMEOUT',0x9111)
GL_OBJECT_TYPE=_C('GL_OBJECT_TYPE',0x9112)
GL_SIGNALED=_C('GL_SIGNALED',0x9119)
GL_SYNC_CONDITION=_C('GL_SYNC_CONDITION',0x9113)
GL_SYNC_FENCE=_C('GL_SYNC_FENCE',0x9116)
GL_SYNC_FLAGS=_C('GL_SYNC_FLAGS',0x9115)
GL_SYNC_FLUSH_COMMANDS_BIT=_C('GL_SYNC_FLUSH_COMMANDS_BIT',0x00000001)
GL_SYNC_GPU_COMMANDS_COMPLETE=_C('GL_SYNC_GPU_COMMANDS_COMPLETE',0x9117)
GL_SYNC_STATUS=_C('GL_SYNC_STATUS',0x9114)
GL_TIMEOUT_EXPIRED=_C('GL_TIMEOUT_EXPIRED',0x911B)
GL_TIMEOUT_IGNORED=_C('GL_TIMEOUT_IGNORED',0xFFFFFFFFFFFFFFFF)
GL_UNSIGNALED=_C('GL_UNSIGNALED',0x9118)
GL_WAIT_FAILED=_C('GL_WAIT_FAILED',0x911D)
@_f
@_p.types(_cs.GLenum,_cs.GLsync,_cs.GLbitfield,_cs.GLuint64)
def glClientWaitSync(sync,flags,timeout):pass
@_f
@_p.types(None,_cs.GLsync)
def glDeleteSync(sync):pass
@_f
@_p.types(_cs.GLsync,_cs.GLenum,_cs.GLbitfield)
def glFenceSync(condition,flags):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLint64Array)
def glGetInteger64v(pname,data):pass
@_f
@_p.types(None,_cs.GLsync,_cs.GLenum,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLintArray)
def glGetSynciv(sync,pname,bufSize,length,values):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLsync)
def glIsSync(sync):pass
@_f
@_p.types(None,_cs.GLsync,_cs.GLbitfield,_cs.GLuint64)
def glWaitSync(sync,flags,timeout):pass
