'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_INTEL_map_texture'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_INTEL_map_texture',error_checker=_errors._error_checker)
GL_LAYOUT_DEFAULT_INTEL=_C('GL_LAYOUT_DEFAULT_INTEL',0)
GL_LAYOUT_LINEAR_CPU_CACHED_INTEL=_C('GL_LAYOUT_LINEAR_CPU_CACHED_INTEL',2)
GL_LAYOUT_LINEAR_INTEL=_C('GL_LAYOUT_LINEAR_INTEL',1)
GL_TEXTURE_MEMORY_LAYOUT_INTEL=_C('GL_TEXTURE_MEMORY_LAYOUT_INTEL',0x83FF)
@_f
@_p.types(ctypes.c_void_p,_cs.GLuint,_cs.GLint,_cs.GLbitfield,arrays.GLintArray,arrays.GLuintArray)
def glMapTexture2DINTEL(texture,level,access,stride,layout):pass
@_f
@_p.types(None,_cs.GLuint)
def glSyncTextureINTEL(texture):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint)
def glUnmapTexture2DINTEL(texture,level):pass
