'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_APPLE_vertex_program_evaluators'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_APPLE_vertex_program_evaluators',error_checker=_errors._error_checker)
GL_VERTEX_ATTRIB_MAP1_APPLE=_C('GL_VERTEX_ATTRIB_MAP1_APPLE',0x8A00)
GL_VERTEX_ATTRIB_MAP1_COEFF_APPLE=_C('GL_VERTEX_ATTRIB_MAP1_COEFF_APPLE',0x8A03)
GL_VERTEX_ATTRIB_MAP1_DOMAIN_APPLE=_C('GL_VERTEX_ATTRIB_MAP1_DOMAIN_APPLE',0x8A05)
GL_VERTEX_ATTRIB_MAP1_ORDER_APPLE=_C('GL_VERTEX_ATTRIB_MAP1_ORDER_APPLE',0x8A04)
GL_VERTEX_ATTRIB_MAP1_SIZE_APPLE=_C('GL_VERTEX_ATTRIB_MAP1_SIZE_APPLE',0x8A02)
GL_VERTEX_ATTRIB_MAP2_APPLE=_C('GL_VERTEX_ATTRIB_MAP2_APPLE',0x8A01)
GL_VERTEX_ATTRIB_MAP2_COEFF_APPLE=_C('GL_VERTEX_ATTRIB_MAP2_COEFF_APPLE',0x8A07)
GL_VERTEX_ATTRIB_MAP2_DOMAIN_APPLE=_C('GL_VERTEX_ATTRIB_MAP2_DOMAIN_APPLE',0x8A09)
GL_VERTEX_ATTRIB_MAP2_ORDER_APPLE=_C('GL_VERTEX_ATTRIB_MAP2_ORDER_APPLE',0x8A08)
GL_VERTEX_ATTRIB_MAP2_SIZE_APPLE=_C('GL_VERTEX_ATTRIB_MAP2_SIZE_APPLE',0x8A06)
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum)
def glDisableVertexAttribAPPLE(index,pname):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum)
def glEnableVertexAttribAPPLE(index,pname):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint,_cs.GLenum)
def glIsVertexAttribEnabledAPPLE(index,pname):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLdouble,_cs.GLdouble,_cs.GLint,_cs.GLint,arrays.GLdoubleArray)
def glMapVertexAttrib1dAPPLE(index,size,u1,u2,stride,order,points):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLfloat,_cs.GLfloat,_cs.GLint,_cs.GLint,arrays.GLfloatArray)
def glMapVertexAttrib1fAPPLE(index,size,u1,u2,stride,order,points):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLdouble,_cs.GLdouble,_cs.GLint,_cs.GLint,_cs.GLdouble,_cs.GLdouble,_cs.GLint,_cs.GLint,arrays.GLdoubleArray)
def glMapVertexAttrib2dAPPLE(index,size,u1,u2,ustride,uorder,v1,v2,vstride,vorder,points):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLfloat,_cs.GLfloat,_cs.GLint,_cs.GLint,_cs.GLfloat,_cs.GLfloat,_cs.GLint,_cs.GLint,arrays.GLfloatArray)
def glMapVertexAttrib2fAPPLE(index,size,u1,u2,ustride,uorder,v1,v2,vstride,vorder,points):pass
